summaryrefslogtreecommitdiffstats
path: root/chrome/browser/ui/webui/constrained_web_dialog_delegate_base.h
diff options
context:
space:
mode:
authoravi@chromium.org <avi@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-12-08 01:23:06 +0000
committeravi@chromium.org <avi@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-12-08 01:23:06 +0000
commitbbe7250added91877c9570465a407aab4a2a7e7e (patch)
treefca09e869668d43450caaa16797503425892b943 /chrome/browser/ui/webui/constrained_web_dialog_delegate_base.h
parentb5641a407904cae6aada72dbb9a4a458ca86d349 (diff)
downloadchromium_src-bbe7250added91877c9570465a407aab4a2a7e7e.zip
chromium_src-bbe7250added91877c9570465a407aab4a2a7e7e.tar.gz
chromium_src-bbe7250added91877c9570465a407aab4a2a7e7e.tar.bz2
Remove TabContents from constrained web dialogs.
BUG=107201 TEST=no visible change Review URL: https://chromiumcodereview.appspot.com/11474011 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@171907 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/ui/webui/constrained_web_dialog_delegate_base.h')
-rw-r--r--chrome/browser/ui/webui/constrained_web_dialog_delegate_base.h19
1 files changed, 11 insertions, 8 deletions
diff --git a/chrome/browser/ui/webui/constrained_web_dialog_delegate_base.h b/chrome/browser/ui/webui/constrained_web_dialog_delegate_base.h
index 42826b5..c814c7d 100644
--- a/chrome/browser/ui/webui/constrained_web_dialog_delegate_base.h
+++ b/chrome/browser/ui/webui/constrained_web_dialog_delegate_base.h
@@ -6,11 +6,14 @@
#define CHROME_BROWSER_UI_WEBUI_CONSTRAINED_WEB_DIALOG_DELEGATE_BASE_H_
#include "base/memory/scoped_ptr.h"
-#include "chrome/browser/ui/tab_contents/tab_contents.h"
#include "chrome/browser/ui/webui/constrained_web_dialog_ui.h"
#include "ui/web_dialogs/web_dialog_ui.h"
#include "ui/web_dialogs/web_dialog_web_contents_delegate.h"
+namespace content {
+class BrowserContext;
+}
+
namespace ui {
class WebDialogDelegate;
}
@@ -21,7 +24,7 @@ class ConstrainedWebDialogDelegateBase
public ui::WebDialogWebContentsDelegate {
public:
ConstrainedWebDialogDelegateBase(
- Profile* profile,
+ content::BrowserContext* browser_context,
ui::WebDialogDelegate* delegate,
WebDialogWebContentsDelegate* tab_delegate);
virtual ~ConstrainedWebDialogDelegateBase();
@@ -34,9 +37,9 @@ class ConstrainedWebDialogDelegateBase
GetWebDialogDelegate() const OVERRIDE;
virtual ui::WebDialogDelegate* GetWebDialogDelegate() OVERRIDE;
virtual void OnDialogCloseFromWebUI() OVERRIDE;
- virtual void ReleaseTabContentsOnDialogClose() OVERRIDE;
- virtual ConstrainedWindow* window() OVERRIDE;
- virtual TabContents* tab() OVERRIDE;
+ virtual void ReleaseWebContentsOnDialogClose() OVERRIDE;
+ virtual ConstrainedWindow* GetWindow() OVERRIDE;
+ virtual content::WebContents* GetWebContents() OVERRIDE;
// WebDialogWebContentsDelegate interface.
virtual void HandleKeyboardEvent(
@@ -54,14 +57,14 @@ class ConstrainedWebDialogDelegateBase
ConstrainedWindow* window_;
// Holds the HTML to display in the constrained dialog.
- scoped_ptr<TabContents> tab_;
+ scoped_ptr<content::WebContents> web_contents_;
// Was the dialog closed from WebUI (in which case |web_dialog_delegate_|'s
// OnDialogClosed() method has already been called)?
bool closed_via_webui_;
- // If true, release |tab_| on close instead of destroying it.
- bool release_tab_on_close_;
+ // If true, release |web_contents_| on close instead of destroying it.
+ bool release_contents_on_close_;
scoped_ptr<WebDialogWebContentsDelegate> override_tab_delegate_;